@@ -5,6 +5,7 @@
 #include "mainwindow.h"
 
 #include <DApplication>
+#include <DWidgetUtil>
 #include <LogManager.h>
 
 DWIDGET_USE_NAMESPACE
@@ -14,16 +15,17 @@ int main(int argc, char *argv[])
 {
     DApplication app(argc, argv);
 
-    app.setApplicationName("deepin-xdgicon-convert");
     app.setProductIcon(QIcon::fromTheme("deepin-xdgicon-convert"));
     app.setApplicationVersion(VERSION);
     app.loadTranslator();
+    app.setApplicationDisplayName(QObject::tr("Theme Icon Converter"));
 
     DLogManager::registerConsoleAppender();
     DLogManager::registerJournalAppender();
 
     MainWindow w;
     w.resize(450, 360);
+    Dtk::Widget::moveToCenter(&w);
     w.show();
 
     return app.exec();
